@@ -1,5 +1,5 @@
 package Git::FastExport;
-$Git::FastExport::VERSION = '0.106';
+$Git::FastExport::VERSION = '0.107';
 use strict;
 use warnings;
 use Carp;
@@ -157,9 +157,13 @@ The original version of this module was created as part of my work
 for BOOKING.COM, which authorized its publication/distribution
 under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Philippe Bruhat (BooK) <book@cpan.org>
+
 =head1 COPYRIGHT
 
-Copyright 2008-2015 Philippe Bruhat (BooK), All Rights Reserved.
+Copyright 2008-2016 Philippe Bruhat (BooK), All Rights Reserved.
 
 =head1 LICENSE
 
