@@ -1,5 +1,5 @@
 package Git::FastExport::Block;
-$Git::FastExport::Block::VERSION = '0.106';
+$Git::FastExport::Block::VERSION = '0.107';
 use strict;
 use warnings;
 
@@ -38,6 +38,8 @@ sub as_string {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Git::FastExport::Block - A block in a fast-export stream
@@ -134,9 +136,13 @@ The original version of this module was created as part of my work
 for BOOKING.COM, which authorized its publication/distribution
 under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+Philippe Bruhat (BooK) <book@cpan.org>
+
 =head1 COPYRIGHT
 
-Copyright 2008-2014 Philippe Bruhat (BooK), All Rights Reserved.
+Copyright 2008-2016 Philippe Bruhat (BooK), All Rights Reserved.
 
 =head1 LICENSE
 
