@@ -1,5 +1,5 @@
 package Git::FastExport::Stitch;
-$Git::FastExport::Stitch::VERSION = '0.106';
+$Git::FastExport::Stitch::VERSION = '0.107';
 use strict;
 use warnings;
 use Cwd qw( cwd );
@@ -84,6 +84,10 @@ sub stitch {
         $name .= "-$suffix";
     }
 
+    # git fast-export appeared in git 1.5.4
+    croak "stitch() requires a git version greater or equal to 1.5.4, this is only version ${\$export->version}"
+      if $export->version_lt('1.5.4');
+
     # initiate the Git::FastExport stream
     my $stream =
       $export->command(qw( fast-export --progress=1 --all --date-order ))
@@ -296,6 +300,8 @@ sub _last_alien_child {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Git::FastExport::Stitch - Stitch together multiple git fast-export streams
@@ -563,9 +569,13 @@ This method is the heart of the stitching algorithm.
 
 B<git-stitch-repo>
 
+=head1 AUTHOR
+
+Philippe Bruhat (BooK) <book@cpan.org>
+
 =head1 COPYRIGHT
 
-Copyright 2008-2015 Philippe Bruhat (BooK), All Rights Reserved.
+Copyright 2008-2016 Philippe Bruhat (BooK), All Rights Reserved.
 
 =head1 LICENSE
 
